from pydantic import BaseModel

class KrBaseModel(BaseModel):
    class Config:
        extra = 'allow'
        underscore_attrs_are_private = True

    def __init__(self, **kw):
        super().__init__(**kw)
        self.__post_init__()

    def __post_init__(self):
        pass



from pydantic import parse_obj_as

class Factory():
    def __init__(self, root_type):
        self.root_type = root_type

    def get_instance(self, config):
        return parse_obj_as(self.root_type, config)



import unittest
import math
import json

from pydantic import parse_obj_as

from . import *

import logging
logger = logging.getLogger(__name__)


class ExampleModel(KrBaseModel):
    pub_var: float = 1
    _pri_var: float = 2

    def __post_init__(self):
        pass

class TestExampleModel(unittest.TestCase):
    def test_example_model(self):
        test_obj = ExampleModel()
        logger.debug(json.dumps(test_obj.dict(), indent=2))

        self.assertEqual(1, 1)
